hexbin_points: Generate a dataset of points for use with 'st_hexbin'

View source: R/example_data.R

hexbin_pointsR Documentation

Generate a dataset of points for use with st_hexbin

Description

Generate a dataset of points for use with st_hexbin

Usage

hexbin_points(n = 1000, bb = c(-72, -63, 39, 46))

Arguments

n

the number of points to generate

bb

4 element numeric of bounding box [left, right, bottom, top]


BigelowLab/rasf documentation built on July 18, 2022, 10:19 p.m.